@@ -69,13 +69,13 @@ import functools
 import logging
 import platform
 import textwrap
+from xopen import xopen
 
 from cutadapt import seqio, __version__
-from cutadapt.xopen import xopen
 from cutadapt.adapters import AdapterParser
 from cutadapt.modifiers import (LengthTagModifier, SuffixRemover, PrefixSuffixAdder,
 	DoubleEncoder, ZeroCapper, PrimerTrimmer, QualityTrimmer, UnconditionalCutter,
-	NEndTrimmer, AdapterCutter, NextseqQualityTrimmer)
+	NEndTrimmer, AdapterCutter, NextseqQualityTrimmer, Shortener)
 from cutadapt.filters import (NoFilter, PairedNoFilter, Redirector, PairedRedirector,
 	LegacyPairedRedirector, TooShortReadFilter, TooLongReadFilter,
 	Demultiplexer, NContentFilter, DiscardUntrimmedFilter, DiscardTrimmedFilter)
@@ -99,50 +99,57 @@ class RestFileWriter(object):
 			print(rest, match.read.name, file=self.file)
 
 
-def process_single_reads(reader, modifiers, filters):
+class SingleEndPipeline:
 	"""
-	Loop over reads, find adapters, trim reads, apply modifiers and
-	output modified reads.
-
-	Return a Statistics object.
+	Processing pipeline that loops over reads and applies modifiers and filters
 	"""
-	n = 0  # no. of processed reads
-	total_bp = 0
-	for read in reader:
-		n += 1
-		total_bp += len(read.sequence)
-		for modifier in modifiers:
-			read = modifier(read)
-		for filter in filters:
-			if filter(read):
-				break
+	def __init__(self, reader, modifiers, filters):
+		self.reader = reader
+		self.modifiers = modifiers
+		self.filters = filters
 
-	return Statistics(n=n, total_bp1=total_bp, total_bp2=None)
+	def run(self):
+		"""Run the pipeline. Return a Statistics object"""
+		n = 0  # no. of processed reads
+		total_bp = 0
+		for read in self.reader:
+			n += 1
+			total_bp += len(read.sequence)
+			for modifier in self.modifiers:
+				read = modifier(read)
+			for filter in self.filters:
+				if filter(read):
+					break
+		return Statistics(n=n, total_bp1=total_bp, total_bp2=None)
 
 
-def process_paired_reads(paired_reader, modifiers1, modifiers2, filters):
+class PairedEndPipeline:
 	"""
-	Loop over reads, find adapters, trim reads, apply modifiers and
-	output modified reads.
-
-	Return a Statistics object.
+	Processing pipeline for paired-end reads.
 	"""
-	n = 0  # no. of processed reads
-	total1_bp = 0
-	total2_bp = 0
-	for read1, read2 in paired_reader:
-		n += 1
-		total1_bp += len(read1.sequence)
-		total2_bp += len(read2.sequence)
-		for modifier in modifiers1:
-			read1 = modifier(read1)
-		for modifier in modifiers2:
-			read2 = modifier(read2)
-		for filter in filters:
-			# Stop writing as soon as one of the filters was successful.
-			if filter(read1, read2):
-				break
-	return Statistics(n=n, total_bp1=total1_bp, total_bp2=total2_bp)
+	def __init__(self, paired_reader, modifiers1, modifiers2, filters):
+		self.paired_reader = paired_reader
+		self.modifiers1 = modifiers1
+		self.modifiers2 = modifiers2
+		self.filters = filters
+
+	def run(self):
+		n = 0  # no. of processed reads
+		total1_bp = 0
+		total2_bp = 0
+		for read1, read2 in self.paired_reader:
+			n += 1
+			total1_bp += len(read1.sequence)
+			total2_bp += len(read2.sequence)
+			for modifier in self.modifiers1:
+				read1 = modifier(read1)
+			for modifier in self.modifiers2:
+				read2 = modifier(read2)
+			for filter in self.filters:
+				# Stop writing as soon as one of the filters was successful.
+				if filter(read1, read2):
+					break
+		return Statistics(n=n, total_bp1=total1_bp, total_bp2=total2_bp)
 
 
 def setup_logging(stdout=False, quiet=False):
@@ -238,6 +245,9 @@ def get_option_parser():
 		help="Assume that quality values in FASTQ are encoded as ascii(quality "
 			"+ QUALITY_BASE). This needs to be set to 64 for some old Illumina "
 			"FASTQ files. Default: %default")
+	group.add_option("--length", "-l", type=int, default=None, metavar="LENGTH",
+			help="Shorten reads to LENGTH. This and the following modifications"
+			"are applied after adapter trimming.")
 	group.add_option("--trim-n", action='store_true', default=False,
 		help="Trim N's on ends of reads.")
 	group.add_option("--length-tag", metavar="TAG",
@@ -605,15 +615,6 @@ def main(cmdlineargs=None, default_outfile=sys.stdout):
 		for adapter in adapters + adapters2:
 			adapter.enable_debug()
 
-	if not adapters and not adapters2 and not cutoffs and \
-			options.nextseq_trim is None and \
-			options.cut == [] and options.cut2 == [] and \
-			options.minimum_length == 0 and \
-			options.maximum_length == sys.maxsize and \
-			quality_filename is None and \
-			options.max_n == -1 and not options.trim_n:
-		parser.error("You need to provide at least one adapter sequence.")
-
 	# Create the single-end processing pipeline (a list of "modifiers")
 	modifiers = []
 	if options.cut:
@@ -638,6 +639,8 @@ def main(cmdlineargs=None, default_outfile=sys.stdout):
 
 	# Modifiers that apply to both reads of paired-end reads unless in legacy mode
 	modifiers_both = []
+	if options.length is not None:
+		modifiers_both.append(Shortener(options.length))
 	if options.trim_n:
 		modifiers_both.append(NEndTrimmer())
 	if options.length_tag:
@@ -680,6 +683,11 @@ def main(cmdlineargs=None, default_outfile=sys.stdout):
 			adapter_cutter2 = None
 		modifiers2.extend(modifiers_both)
 
+	if paired:
+		pipeline = PairedEndPipeline(reader, modifiers, modifiers2, filters)
+	else:
+		pipeline = SingleEndPipeline(reader, modifiers, filters)
+
 	logger.info("This is cutadapt %s with Python %s", __version__, platform.python_version())
 	logger.info("Command line parameters: %s", " ".join(cmdlineargs))
 	logger.info("Trimming %s adapter%s with at most %.1f%% errors in %s mode ...",
@@ -696,10 +704,7 @@ def main(cmdlineargs=None, default_outfile=sys.stdout):
 
 	start_time = time.clock()
 	try:
-		if paired:
-			stats = process_paired_reads(reader, modifiers, modifiers2, filters)
-		else:
-			stats = process_single_reads(reader, modifiers, filters)
+		stats = pipeline.run()
 	except KeyboardInterrupt as e:
 		print("Interrupted", file=sys.stderr)
 		sys.exit(130)
